// --8<--8<--8<--8<--
//
// Copyright (C) 2006 Smithsonian Astrophysical Observatory
//
// This file is part of scatter
//
// scatter is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// scatter is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the
//       Free Software Foundation, Inc.
//       51 Franklin Street, Fifth Floor
//       Boston, MA  02110-1301, USA
//
// -->8-->8-->8-->8--

#include "Photon.h"

using namespace SAOTrace::BPipeX;

#include <suplib/debug.h>

namespace Scatter {

    Photon::Photon( Simple& bpipe ) throw ( Exception )  {

	bpipe.add( DpktF<double>( "phi" ) );
	bpipe.add( DpktF<double>( "theta" ) );

	if ( ! dbflag( "phi" ) )
	    bpipe.delete_dpktf( "phi" );

	if ( ! dbflag( "theta" ) )
	    bpipe.delete_dpktf( "theta" );

	bpipe.map();
	bpipe.write_hdr();

        _position        = bpipe.dpktf_data<DVector3>( "position" );
        _direction       = bpipe.dpktf_data<DVector3>( "direction" );
        _surface_norm    = bpipe.dpktf_data<DVector3>( "surface_norm" );
	_energy          = bpipe.dpktf_data<double>( "energy" );
	_theta           = bpipe.dpktf_data<double>( "theta" );
	_phi  	         = bpipe.dpktf_data<double>( "phi" );
	_id 	         = bpipe.dpktf_data<unsigned int>( "id" );
	_surf_missed     = bpipe.dpktf_data<unsigned int>( "surf_missed" );

    }

    void
    Photon::dump( ) {

	char buf[1000];

	bpipe_sprintf( buf, static_cast<const void*>(_id),
		       BPDType_uint, NULL );
	std::cerr << "id: " << buf << "\n";

	bpipe_sprintf( buf, static_cast<const void*>(_position),
		       BPDType_DVector3, NULL );
	std::cerr << "position: " << buf << "\n";

	bpipe_sprintf( buf, static_cast<const void*>(_direction),
		       BPDType_DVector3, NULL );
	std::cerr << "direction: " << buf << "\n";

	bpipe_sprintf( buf, static_cast<const void*>(_surface_norm),
		       BPDType_DVector3, NULL );
	std::cerr << "surface_norm: " << buf << "\n";




    }


}
